@@ -1,4 +1,6 @@
 .onAttach <- function(libname, pkgname) {
+  options(future.globals.maxSize = 100*1024^3)
+  data.table::setDTthreads(threads = 1, restore_after_fork = FALSE)
   packageStartupMessage("
 
                                                         _/_/_/    _/_/_/    _/_/_/    _/_/_/
